#
# spec file for package libXrender
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libXrender
VCS: https://src.suse.de/SLFO-pool/libXrender#428f96fc45003a89790d49a91f01b41dd0189eb09cfe7009e058c1b92a5a3889
%define lname	libXrender1
Version:        0.9.11
Release:        slfo.1.1_1.2
Summary:        X Rendering Extension library
License:        MIT
Group:          Development/Libraries/C and C++
URL:            http://cgit.freedesktop.org/xorg/lib/libXrender/

#Git-Clone:	git://anongit.freedesktop.org/xorg/lib/libXrender
#Git-Web:	http://cgit.freedesktop.org/xorg/lib/libXrender/
Source:         http://xorg.freedesktop.org/releases/individual/lib/%{name}-%{version}.tar.xz
Source1:        baselibs.conf
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
#git#BuildRequires:	autoconf >= 2.60, automake, libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(renderproto) >= 0.9
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8

%description
The Xrender library is designed as a lightweight library interface to
the Render extension.

%package -n %lname
Summary:        X Rendering Extension library
# O/P added for 12.2
Group:          System/Libraries
Provides:       xorg-x11-libXrender = 7.6_%version-%release
Obsoletes:      xorg-x11-libXrender < 7.6_%version-%release

%description -n %lname
The Xrender library is designed as a lightweight library interface to
the Render extension.

%package devel
Summary:        Development files for the X11 Render Extension library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
# O/P added for 12.2
Provides:       xorg-x11-libXrender-devel = 7.6_%version-%release
Obsoletes:      xorg-x11-libXrender-devel < 7.6_%version-%release

%description devel
The Xrender library is designed as a lightweight library interface to
the Render extension.

This package contains the development headers for the library found
in %lname.

%prep
%setup -q

%build
%configure --docdir=%_docdir/%name --disable-static
make %{?_smp_mflags}

%install
make install DESTDIR="%buildroot"
rm -f "%buildroot/%_libdir"/*.la

%post -n %lname -p /sbin/ldconfig

%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%defattr(-,root,root)
%_libdir/libXrender.so.1*

%files devel
%defattr(-,root,root)
%_includedir/X11/*
%_libdir/libXrender.so
%_libdir/pkgconfig/xrender.pc
%_docdir/%name

%changelog
* Sat Oct 22 2022 sndirsch@suse.com
- Update to version 0.9.11
  * Update README for gitlab migration
  * Update configure.ac bug URL for gitlab migration
  * Fix spelling/wording issues
  * gitlab CI: add a basic build test
  * Remove unnecessary casts from malloc & free calls
  * Reduce variable scopes as recommended by cppcheck
  * Resolve -Wsign-compare warnings
  * Rename xDepth to xPDepth to quiet -Wshadow warnings
  * fix coredumps in XRenderComputeTrapezoids (issue #1)
  * autogen.sh: use quoted string variables
  * autogen: add default patch prefix
  * WIP: Documentation
  * autogen.sh: use exec instead of waiting for configure to finish
  * Add missing HAVE_CONFIG_H guard to Xrenderint.h
  * amend cppcheck-scope change, fixing c89 build
  * additional cppcheck-scope warning
  * cppcheck (removing unused assignment lets variable scope reduction)
  * use casts to reduce compiler warnings (no object change)
  * use _Xconst with DataInt32/DataInt16/memcpy to reduce strict compiler warnings
  * use _X_UNUSED for compiler-warnings
  * whitespace fix
  * fix regression
  * fix coredumps in XRenderComputeTrapezoids (issue #1)
  * autogen.sh: use quoted string variables
  * autogen: add default patch prefix
  * WIP: Documentation
  * autogen.sh: use exec instead of waiting for configure to finish
  * Add missing HAVE_CONFIG_H guard to Xrenderint.h
  * amend cppcheck-scope change, fixing c89 build
  * additional cppcheck-scope warning
  * cppcheck (removing unused assignment lets variable scope reduction)
  * use casts to reduce compiler warnings (no object change)
  * use _Xconst with DataInt32/DataInt16/memcpy to reduce strict compiler warnings
  * use _X_UNUSED for compiler-warnings
  * whitespace fix
  * fix regression
* Sat Oct 29 2016 tobias.johannes.klausmann@mni.thm.de
- Update to version 0.9.10:
  + Fix documentation to explicitly mention premultiplied alpha
  + Avoid OOB write in XRenderQueryFilters
  + Validate lengths while parsing server data.
* Mon May  4 2015 sndirsch@suse.com
- Update to version 0.9.9
  * Fix request length calculation for XRenderCompositeText32
  * Remove fallback for _XEatDataWords, require libX11 1.6 for it
* Fri Jun 14 2013 tobias.johannes.klausmann@mni.thm.de
- Update to version 0.9.8:
  This bugfix release delivers the fixes for the recently announced security
  issue CVE-2013-1987.
* Sun Feb 17 2013 jengelh@inai.de
- Use more robust make install call
* Wed Apr 11 2012 vuntz@opensuse.org
- Update to version 0.9.7:
  + Fix alpha premultiplication in XRenderParseColor
  + Compiler warning fixes
  + Documentation typo fixes
  + Build configuration fixes
* Fri Feb 17 2012 sndirsch@suse.com
- fixed name of .changes (follows rename)
* Tue Dec 21 2010 sndirsch@novell.com
- bumped version number to 7.6_0.9.6
* Sat Sep  4 2010 sndirsch@novell.com
- update to release 0.9.6
- bumped version number to 7.5_0.9.6
- fixed Summary/Group entries in -devel package
* Sun Apr  4 2010 sndirsch@suse.de
- libXrender 0.9.5
- obsoletes libXrender-commit-f6f784c.diff
- bumped version number to 7.5
* Mon Dec 28 2009 sndirsch@suse.de
- libXrender-commit-f6f784c.diff
  * Use Data instead of Data32 to avoid truncating the filter
    parameters on 64-bit systems (bnc #567454)
* Mon Dec 14 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Sat May  2 2009 eich@suse.de
- revert static library and .la file removal
  for SUSE versions <= 11.1.
* Tue Apr 21 2009 crrodriguez@suse.de
- remove static libraries and "la" files
- run ldconfig in postun
* Thu Sep 11 2008 sndirsch@suse.de
- bumped release number to 7.4
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Sat Sep 29 2007 sndirsch@suse.de
- bumped version to 7.3
* Thu Sep  6 2007 sndirsch@suse.de
- libXrender 0.9.4
  * This release is just a build fix for some applications
    requiring libXrender.
* Fri Aug 24 2007 sndirsch@suse.de
- libXrender 0.9.3
  * Properly set length field in gradient requests (bug 9526).
* Sat Oct 14 2006 sndirsch@suse.de
- updated to X.Org 7.2RC1
* Wed Aug  2 2006 sndirsch@suse.de
- fix setup line
* Fri Jul 28 2006 sndirsch@suse.de
- use "-fno-strict-aliasing"
* Thu Jul 27 2006 sndirsch@suse.de
- use $RPM_OPT_FLAGS
- remove existing /usr/include/X11 symlink in %%pre
* Fri Jun 23 2006 sndirsch@suse.de
- created package
